@@ -3,11 +3,11 @@ package main
 import (
 	"fmt"
 
-	"github.com/crowdsecurity/crowdsec/pkg/cwhub"
-
+	"github.com/fatih/color"
 	log "github.com/sirupsen/logrus"
-
 	"github.com/spf13/cobra"
+
+	"github.com/crowdsecurity/crowdsec/pkg/cwhub"
 )
 
 func NewCollectionsCmd() *cobra.Command {
@@ -17,22 +17,23 @@ func NewCollectionsCmd() *cobra.Command {
 		Long:  `Install/Remove/Upgrade/Inspect collections from the CrowdSec Hub.`,
 		/*TBD fix help*/
 		Args:              cobra.MinimumNArgs(1),
+		Aliases:           []string{"collection"},
 		DisableAutoGenTag: true,
 		PersistentPreRunE: func(cmd *cobra.Command, args []string) error {
 			if err := csConfig.LoadHub(); err != nil {
-				log.Fatalf(err.Error())
+				log.Fatal(err)
 			}
 			if csConfig.Hub == nil {
 				return fmt.Errorf("you must configure cli before interacting with hub")
 			}
 
-			if err := setHubBranch(); err != nil {
+			if err := cwhub.SetHubBranch(); err != nil {
 				return fmt.Errorf("error while setting hub branch: %s", err)
 			}
 
 			if err := cwhub.GetHubIdx(csConfig.Hub); err != nil {
+				log.Info("Run 'sudo cscli hub update' to get the hub index")
 				log.Fatalf("Failed to get Hub index : %v", err)
-				log.Infoln("Run 'sudo cscli hub update' to get the hub index")
 			}
 
 			return nil
@@ -45,21 +46,37 @@ func NewCollectionsCmd() *cobra.Command {
 		},
 	}
 
+	var ignoreError bool
 	var cmdCollectionsInstall = &cobra.Command{
-		Use:               "install collection",
-		Short:             "Install given collection(s)",
-		Long:              `Fetch and install given collection(s) from hub`,
-		Example:           `cscli collections install crowdsec/xxx crowdsec/xyz`,
-		Args:              cobra.MinimumNArgs(1),
+		Use:     "install collection",
+		Short:   "Install given collection(s)",
+		Long:    `Fetch and install given collection(s) from hub`,
+		Example: `cscli collections install crowdsec/xxx crowdsec/xyz`,
+		Args:    cobra.MinimumNArgs(1),
+		ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+			return compAllItems(cwhub.COLLECTIONS, args, toComplete)
+		},
 		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			for _, name := range args {
-				InstallItem(name, cwhub.COLLECTIONS, forceAction)
+				t := cwhub.GetItem(cwhub.COLLECTIONS, name)
+				if t == nil {
+					nearestItem, score := GetDistance(cwhub.COLLECTIONS, name)
+					Suggest(cwhub.COLLECTIONS, name, nearestItem.Name, score, ignoreError)
+					continue
+				}
+				if err := cwhub.InstallItem(csConfig, name, cwhub.COLLECTIONS, forceAction, downloadOnly); err != nil {
+					if !ignoreError {
+						log.Fatalf("Error while installing '%s': %s", name, err)
+					}
+					log.Errorf("Error while installing '%s': %s", name, err)
+				}
 			}
 		},
 	}
 	cmdCollectionsInstall.PersistentFlags().BoolVarP(&downloadOnly, "download-only", "d", false, "Only download packages, don't enable")
 	cmdCollectionsInstall.PersistentFlags().BoolVar(&forceAction, "force", false, "Force install : Overwrite tainted and outdated files")
+	cmdCollectionsInstall.PersistentFlags().BoolVar(&ignoreError, "ignore", false, "Ignore errors when installing multiple collections")
 	cmdCollections.AddCommand(cmdCollectionsInstall)
 
 	var cmdCollectionsRemove = &cobra.Command{
@@ -67,26 +84,34 @@ func NewCollectionsCmd() *cobra.Command {
 		Short:             "Remove given collection(s)",
 		Long:              `Remove given collection(s) from hub`,
 		Example:           `cscli collections remove crowdsec/xxx crowdsec/xyz`,
-		Args:              cobra.MinimumNArgs(1),
+		Aliases:           []string{"delete"},
 		DisableAutoGenTag: true,
+		ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+			return compInstalledItems(cwhub.COLLECTIONS, args, toComplete)
+		},
 		Run: func(cmd *cobra.Command, args []string) {
 			if all {
-				RemoveMany(cwhub.COLLECTIONS, "")
-			} else {
-				for _, name := range args {
-					if !forceAction {
-						item := cwhub.GetItem(cwhub.COLLECTIONS, name)
-						if item == nil {
-							log.Fatalf("unable to retrieve: %s\n", name)
-						}
-						if len(item.BelongsToCollections) > 0 {
-							log.Warningf("%s belongs to other collections :\n%s\n", name, item.BelongsToCollections)
-							log.Printf("Run 'sudo cscli collections remove %s --force' if you want to force remove this sub collection\n", name)
-							continue
-						}
+				cwhub.RemoveMany(csConfig, cwhub.COLLECTIONS, "", all, purge, forceAction)
+				return
+			}
+
+			if len(args) == 0 {
+				log.Fatal("Specify at least one collection to remove or '--all' flag.")
+			}
+
+			for _, name := range args {
+				if !forceAction {
+					item := cwhub.GetItem(cwhub.COLLECTIONS, name)
+					if item == nil {
+						log.Fatalf("unable to retrieve: %s\n", name)
+					}
+					if len(item.BelongsToCollections) > 0 {
+						log.Warningf("%s belongs to other collections :\n%s\n", name, item.BelongsToCollections)
+						log.Printf("Run 'sudo cscli collections remove %s --force' if you want to force remove this sub collection\n", name)
+						continue
 					}
-					RemoveMany(cwhub.COLLECTIONS, name)
 				}
+				cwhub.RemoveMany(csConfig, cwhub.COLLECTIONS, name, all, purge, forceAction)
 			}
 		},
 	}
@@ -101,15 +126,18 @@ func NewCollectionsCmd() *cobra.Command {
 		Long:              `Fetch and upgrade given collection(s) from hub`,
 		Example:           `cscli collections upgrade crowdsec/xxx crowdsec/xyz`,
 		DisableAutoGenTag: true,
+		ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+			return compInstalledItems(cwhub.COLLECTIONS, args, toComplete)
+		},
 		Run: func(cmd *cobra.Command, args []string) {
 			if all {
-				UpgradeConfig(cwhub.COLLECTIONS, "", forceAction)
+				cwhub.UpgradeConfig(csConfig, cwhub.COLLECTIONS, "", forceAction)
 			} else {
 				if len(args) == 0 {
 					log.Fatalf("no target collection to upgrade")
 				}
 				for _, name := range args {
-					UpgradeConfig(cwhub.COLLECTIONS, name, forceAction)
+					cwhub.UpgradeConfig(csConfig, cwhub.COLLECTIONS, name, forceAction)
 				}
 			}
 		},
@@ -125,6 +153,9 @@ func NewCollectionsCmd() *cobra.Command {
 		Example:           `cscli collections inspect crowdsec/xxx crowdsec/xyz`,
 		Args:              cobra.MinimumNArgs(1),
 		DisableAutoGenTag: true,
+		ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+			return compInstalledItems(cwhub.COLLECTIONS, args, toComplete)
+		},
 		Run: func(cmd *cobra.Command, args []string) {
 			for _, name := range args {
 				InspectItem(name, cwhub.COLLECTIONS)
@@ -142,7 +173,7 @@ func NewCollectionsCmd() *cobra.Command {
 		Args:              cobra.ExactArgs(0),
 		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
-			ListItems([]string{cwhub.COLLECTIONS}, args, false, true)
+			ListItems(color.Output, []string{cwhub.COLLECTIONS}, args, false, true, all)
 		},
 	}
 	cmdCollectionsList.PersistentFlags().BoolVarP(&all, "all", "a", false, "List disabled items as well")
