@@ -10,16 +10,16 @@ import (
 	"net/url"
 	"os"
 
+	"github.com/fatih/color"
+	"github.com/go-openapi/strfmt"
+	log "github.com/sirupsen/logrus"
+	"github.com/spf13/cobra"
+
 	"github.com/crowdsecurity/crowdsec/pkg/apiclient"
 	"github.com/crowdsecurity/crowdsec/pkg/csconfig"
 	"github.com/crowdsecurity/crowdsec/pkg/cwhub"
 	"github.com/crowdsecurity/crowdsec/pkg/cwversion"
 	"github.com/crowdsecurity/crowdsec/pkg/types"
-	"github.com/enescakir/emoji"
-	"github.com/go-openapi/strfmt"
-	"github.com/olekukonko/tablewriter"
-	log "github.com/sirupsen/logrus"
-	"github.com/spf13/cobra"
 )
 
 func NewConsoleCmd() *cobra.Command {
@@ -33,11 +33,11 @@ func NewConsoleCmd() *cobra.Command {
 				var fdErr *fs.PathError
 				if errors.As(err, &fdErr) {
 					log.Fatalf("Unable to load Local API : %s", fdErr)
-				} else if err != nil {
-					log.Fatalf("Unable to load required Local API Configuration : %s", err)
-				} else {
-					log.Fatal("Local API is disabled, please run this command on the local API machine")
 				}
+				if err != nil {
+					log.Fatalf("Unable to load required Local API Configuration : %s", err)
+				}
+				log.Fatal("Local API is disabled, please run this command on the local API machine")
 			}
 			if csConfig.DisableAPI {
 				log.Fatal("Local API is disabled, please run this command on the local API machine")
@@ -53,6 +53,7 @@ func NewConsoleCmd() *cobra.Command {
 	}
 
 	name := ""
+	overwrite := false
 	tags := []string{}
 
 	cmdEnroll := &cobra.Command{
@@ -77,17 +78,17 @@ After running this command your will need to validate the enrollment in the weba
 			}
 
 			if err := csConfig.LoadHub(); err != nil {
-				log.Fatalf(err.Error())
+				log.Fatal(err)
 			}
 
 			if err := cwhub.GetHubIdx(csConfig.Hub); err != nil {
 				log.Fatalf("Failed to load hub index : %s", err)
-				log.Infoln("Run 'sudo cscli hub update' to get the hub index")
+				log.Info("Run 'sudo cscli hub update' to get the hub index")
 			}
 
-			scenarios, err := cwhub.GetUpstreamInstalledScenariosAsString()
+			scenarios, err := cwhub.GetInstalledScenariosAsString()
 			if err != nil {
-				log.Fatalf("failed to get scenarios : %s", err.Error())
+				log.Fatalf("failed to get scenarios : %s", err)
 			}
 
 			if len(scenarios) == 0 {
@@ -102,10 +103,14 @@ After running this command your will need to validate the enrollment in the weba
 				URL:           apiURL,
 				VersionPrefix: "v2",
 			})
-			_, err = c.Auth.EnrollWatcher(context.Background(), args[0], name, tags)
+			resp, err := c.Auth.EnrollWatcher(context.Background(), args[0], name, tags, overwrite)
 			if err != nil {
 				log.Fatalf("Could not enroll instance: %s", err)
 			}
+			if resp.Response.StatusCode == 200 && !overwrite {
+				log.Warning("Instance already enrolled. You can use '--overwrite' to force enroll")
+				return
+			}
 
 			SetConsoleOpts(csconfig.CONSOLE_CONFIGS, true)
 			if err := csConfig.API.Server.DumpConsoleConfig(); err != nil {
@@ -117,6 +122,7 @@ After running this command your will need to validate the enrollment in the weba
 		},
 	}
 	cmdEnroll.Flags().StringVarP(&name, "name", "n", "", "Name to display in the console")
+	cmdEnroll.Flags().BoolVarP(&overwrite, "overwrite", "", false, "Force enroll the instance")
 	cmdEnroll.Flags().StringSliceVarP(&tags, "tags", "t", tags, "Tags to display in the console")
 	cmdConsole.AddCommand(cmdEnroll)
 
@@ -125,27 +131,25 @@ After running this command your will need to validate the enrollment in the weba
 	cmdEnable := &cobra.Command{
 		Use:     "enable [feature-flag]",
 		Short:   "Enable a feature flag",
-		Example: "enable alerts-tainted",
+		Example: "enable tainted",
 		Long: `
 Enable given information push to the central API. Allows to empower the console`,
 		ValidArgs:         csconfig.CONSOLE_CONFIGS,
-		Args:              cobra.MinimumNArgs(1),
 		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			if enableAll {
 				SetConsoleOpts(csconfig.CONSOLE_CONFIGS, true)
-			} else {
-				SetConsoleOpts(args, true)
-			}
-
-			if err := csConfig.API.Server.DumpConsoleConfig(); err != nil {
-				log.Fatalf("failed writing console config : %s", err)
-			}
-			if enableAll {
 				log.Infof("All features have been enabled successfully")
 			} else {
+				if len(args) == 0 {
+					log.Fatalf("You must specify at least one feature to enable")
+				}
+				SetConsoleOpts(args, true)
 				log.Infof("%v have been enabled", args)
 			}
+			if err := csConfig.API.Server.DumpConsoleConfig(); err != nil {
+				log.Fatalf("failed writing console config : %s", err)
+			}
 			log.Infof(ReloadMessage())
 		},
 	}
@@ -155,7 +159,7 @@ Enable given information push to the central API. Allows to empower the console`
 	cmdDisable := &cobra.Command{
 		Use:     "disable [feature-flag]",
 		Short:   "Disable a feature flag",
-		Example: "disable alerts-tainted",
+		Example: "disable tainted",
 		Long: `
 Disable given information push to the central API.`,
 		ValidArgs:         csconfig.CONSOLE_CONFIGS,
@@ -185,39 +189,12 @@ Disable given information push to the central API.`,
 	cmdConsoleStatus := &cobra.Command{
 		Use:               "status [feature-flag]",
 		Short:             "Shows status of one or all feature flags",
-		Example:           "status alerts-tainted",
+		Example:           "status tainted",
 		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			switch csConfig.Cscli.Output {
 			case "human":
-				table := tablewriter.NewWriter(os.Stdout)
-
-				table.SetHeaderAlignment(tablewriter.ALIGN_LEFT)
-				table.SetAlignment(tablewriter.ALIGN_LEFT)
-				table.SetHeader([]string{"Option Name", "Activated", "Description"})
-				for _, option := range csconfig.CONSOLE_CONFIGS {
-					switch option {
-					case csconfig.SEND_CUSTOM_SCENARIOS:
-						activated := string(emoji.CrossMark)
-						if *csConfig.API.Server.ConsoleConfig.ShareCustomScenarios {
-							activated = string(emoji.CheckMarkButton)
-						}
-						table.Append([]string{option, activated, "Send alerts from custom scenarios to the console"})
-					case csconfig.SEND_MANUAL_SCENARIOS:
-						activated := string(emoji.CrossMark)
-						if *csConfig.API.Server.ConsoleConfig.ShareManualDecisions {
-							activated = string(emoji.CheckMarkButton)
-						}
-						table.Append([]string{option, activated, "Send manual decisions to the console"})
-					case csconfig.SEND_TAINTED_SCENARIOS:
-						activated := string(emoji.CrossMark)
-						if *csConfig.API.Server.ConsoleConfig.ShareTaintedScenarios {
-							activated = string(emoji.CheckMarkButton)
-						}
-						table.Append([]string{option, activated, "Send alerts from tainted scenarios to the console"})
-					}
-				}
-				table.Render()
+				cmdConsoleStatusTable(color.Output, *csConfig)
 			case "json":
 				data, err := json.MarshalIndent(csConfig.API.Server.ConsoleConfig, "", "  ")
 				if err != nil {
