@@ -69,7 +69,7 @@ func runOutput(input chan types.Event, overflow chan types.Event, buckets *leaky
 	var cache []types.RuntimeAlert
 	var cacheMutex sync.Mutex
 
-	scenarios, err := cwhub.GetUpstreamInstalledScenariosAsString()
+	scenarios, err := cwhub.GetInstalledScenariosAsString()
 	if err != nil {
 		return errors.Wrapf(err, "loading list of installed hub scenarios: %s", err)
 	}
@@ -88,7 +88,7 @@ func runOutput(input chan types.Event, overflow chan types.Event, buckets *leaky
 		UserAgent:      fmt.Sprintf("crowdsec/%s", cwversion.VersionStr()),
 		URL:            apiURL,
 		VersionPrefix:  "v1",
-		UpdateScenario: cwhub.GetUpstreamInstalledScenariosAsString,
+		UpdateScenario: cwhub.GetInstalledScenariosAsString,
 	})
 	if err != nil {
 		return errors.Wrapf(err, "new client api: %s", err)
@@ -100,6 +100,9 @@ func runOutput(input chan types.Event, overflow chan types.Event, buckets *leaky
 	}); err != nil {
 		return errors.Wrapf(err, "authenticate watcher (%s)", apiConfig.Login)
 	}
+	//start the heartbeat service
+	log.Debugf("Starting HeartBeat service")
+	Client.HeartBeat.StartHeartBeat(context.Background(), &outputsTomb)
 LOOP:
 	for {
 		select {
@@ -122,8 +125,6 @@ LOOP:
 			if len(cache) > 0 {
 				cacheMutex.Lock()
 				cachecopy := cache
-				newcache := make([]types.RuntimeAlert, 0)
-				cache = newcache
 				cacheMutex.Unlock()
 				if err := PushAlerts(cachecopy, Client); err != nil {
 					log.Errorf("while pushing leftovers to api : %s", err)
@@ -143,10 +144,6 @@ LOOP:
 				buckets.Bucket_map.Delete(event.Overflow.Mapkey)
 				break
 			}
-			if event.Overflow.Reprocess {
-				log.Debugf("Overflow being reprocessed.")
-				input <- event
-			}
 			/* process post overflow parser nodes */
 			event, err := parser.Parse(postOverflowCTX, event, postOverflowNodes)
 			if err != nil {
@@ -157,6 +154,10 @@ LOOP:
 				log.Printf("[%s] is whitelisted, skip.", *event.Overflow.Alert.Message)
 				continue
 			}
+			if event.Overflow.Reprocess {
+				log.Debugf("Overflow being reprocessed.")
+				input <- event
+			}
 			if dumpStates {
 				continue
 			}
