@@ -1,7 +1,7 @@
 package main
 
 import (
-	"errors"
+	"time"
 
 	"github.com/prometheus/client_golang/prometheus"
 	log "github.com/sirupsen/logrus"
@@ -28,12 +28,14 @@ LOOP:
 			}
 			globalParserHits.With(prometheus.Labels{"source": event.Line.Src, "type": event.Line.Module}).Inc()
 
+			startParsing := time.Now()
 			/* parse the log using magic */
-			parsed, error := parser.Parse(parserCTX, event, nodes)
-			if error != nil {
-				log.Errorf("failed parsing : %v\n", error)
-				return errors.New("parsing failed :/")
+			parsed, err := parser.Parse(parserCTX, event, nodes)
+			if err != nil {
+				log.Errorf("failed parsing : %v\n", err)
 			}
+			elapsed := time.Since(startParsing)
+			globalParsingHistogram.With(prometheus.Labels{"source": event.Line.Src, "type": event.Line.Module}).Observe(elapsed.Seconds())
 			if !parsed.Process {
 				globalParserHitsKo.With(prometheus.Labels{"source": event.Line.Src, "type": event.Line.Module}).Inc()
 				log.Debugf("Discarding line %+v", parsed)
