@@ -10,10 +10,10 @@ import (
 	"strings"
 	"time"
 
-	"github.com/ahmetb/dlog"
 	"github.com/crowdsecurity/crowdsec/pkg/acquisition/configuration"
 	leaky "github.com/crowdsecurity/crowdsec/pkg/leakybucket"
 	"github.com/crowdsecurity/crowdsec/pkg/types"
+	"github.com/crowdsecurity/dlog"
 	dockerTypes "github.com/docker/docker/api/types"
 	"github.com/docker/docker/client"
 
@@ -64,6 +64,7 @@ type ContainerConfig struct {
 	t      *tomb.Tomb
 	logger *log.Entry
 	Labels map[string]string
+	Tty    bool
 }
 
 func (d *DockerSource) Configure(Config []byte, logger *log.Entry) error {
@@ -284,9 +285,14 @@ func (d *DockerSource) OneShotAcquisition(out chan types.Event, t *tomb.Tomb) er
 				return err
 			}
 			// we use this library to normalize docker API logs (cf. https://ahmet.im/blog/docker-logs-api-binary-format-explained/)
-			reader := dlog.NewReader(dockerReader)
 			foundOne = true
-			scanner := bufio.NewScanner(reader)
+			var scanner *bufio.Scanner
+			if containerConfig.Tty {
+				scanner = bufio.NewScanner(dockerReader)
+			} else {
+				reader := dlog.NewReader(dockerReader)
+				scanner = bufio.NewScanner(reader)
+			}
 			for scanner.Scan() {
 				line := scanner.Text()
 				if line == "" {
@@ -300,10 +306,14 @@ func (d *DockerSource) OneShotAcquisition(out chan types.Event, t *tomb.Tomb) er
 				l.Process = true
 				l.Module = d.GetName()
 				linesRead.With(prometheus.Labels{"source": containerConfig.Name}).Inc()
-				evt := types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.LIVE}
+				evt := types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.TIMEMACHINE}
 				out <- evt
 				d.logger.Debugf("Sent line to parsing: %+v", evt.Line.Raw)
 			}
+			err = scanner.Err()
+			if err != nil {
+				d.logger.Errorf("Got error from docker read: %s", err)
+			}
 			d.runningContainerState[container.ID] = containerConfig
 		}
 	}
@@ -311,7 +321,7 @@ func (d *DockerSource) OneShotAcquisition(out chan types.Event, t *tomb.Tomb) er
 	t.Kill(nil)
 
 	if !foundOne {
-		return fmt.Errorf("no docker found, can't run one shot acquisition")
+		return fmt.Errorf("no container found named: %s, can't run one shot acquisition", d.Config.ContainerName[0])
 	}
 
 	return nil
@@ -333,10 +343,18 @@ func (d *DockerSource) CanRun() error {
 	return nil
 }
 
+func (d *DockerSource) getContainerTTY(containerId string) bool {
+	containerDetails, err := d.Client.ContainerInspect(context.Background(), containerId)
+	if err != nil {
+		return false
+	}
+	return containerDetails.Config.Tty
+}
+
 func (d *DockerSource) EvalContainer(container dockerTypes.Container) (*ContainerConfig, bool) {
 	for _, containerID := range d.Config.ContainerID {
 		if containerID == container.ID {
-			return &ContainerConfig{ID: container.ID, Name: container.Names[0], Labels: d.Config.Labels}, true
+			return &ContainerConfig{ID: container.ID, Name: container.Names[0], Labels: d.Config.Labels, Tty: d.getContainerTTY(container.ID)}, true
 		}
 	}
 
@@ -346,7 +364,7 @@ func (d *DockerSource) EvalContainer(container dockerTypes.Container) (*Containe
 				name = name[1:]
 			}
 			if name == containerName {
-				return &ContainerConfig{ID: container.ID, Name: name, Labels: d.Config.Labels}, true
+				return &ContainerConfig{ID: container.ID, Name: name, Labels: d.Config.Labels, Tty: d.getContainerTTY(container.ID)}, true
 			}
 		}
 
@@ -354,14 +372,14 @@ func (d *DockerSource) EvalContainer(container dockerTypes.Container) (*Containe
 
 	for _, cont := range d.compiledContainerID {
 		if matched := cont.Match([]byte(container.ID)); matched {
-			return &ContainerConfig{ID: container.ID, Name: container.Names[0], Labels: d.Config.Labels}, true
+			return &ContainerConfig{ID: container.ID, Name: container.Names[0], Labels: d.Config.Labels, Tty: d.getContainerTTY(container.ID)}, true
 		}
 	}
 
 	for _, cont := range d.compiledContainerName {
 		for _, name := range container.Names {
 			if matched := cont.Match([]byte(name)); matched {
-				return &ContainerConfig{ID: container.ID, Name: name, Labels: d.Config.Labels}, true
+				return &ContainerConfig{ID: container.ID, Name: name, Labels: d.Config.Labels, Tty: d.getContainerTTY(container.ID)}, true
 			}
 		}
 
@@ -395,7 +413,7 @@ func (d *DockerSource) WatchContainer(monitChan chan *ContainerConfig, deleteCha
 						delete(d.runningContainerState, idx)
 					}
 				} else {
-					log.Errorf("container list err: %s", err.Error())
+					log.Errorf("container list err: %s", err)
 				}
 				continue
 			}
@@ -444,19 +462,25 @@ func ReadTailScanner(scanner *bufio.Scanner, out chan string, t *tomb.Tomb) erro
 	for scanner.Scan() {
 		out <- scanner.Text()
 	}
-	return nil
+	return scanner.Err()
 }
 
-func (d *DockerSource) TailDocker(container *ContainerConfig, outChan chan types.Event) error {
+func (d *DockerSource) TailDocker(container *ContainerConfig, outChan chan types.Event, deleteChan chan *ContainerConfig) error {
 	container.logger.Infof("start tail for container %s", container.Name)
 	dockerReader, err := d.Client.ContainerLogs(context.Background(), container.ID, *d.containerLogsOptions)
 	if err != nil {
 		container.logger.Errorf("unable to read logs from container: %+v", err)
 		return err
 	}
+
+	var scanner *bufio.Scanner
 	// we use this library to normalize docker API logs (cf. https://ahmet.im/blog/docker-logs-api-binary-format-explained/)
-	reader := dlog.NewReader(dockerReader)
-	scanner := bufio.NewScanner(reader)
+	if container.Tty {
+		scanner = bufio.NewScanner(dockerReader)
+	} else {
+		reader := dlog.NewReader(dockerReader)
+		scanner = bufio.NewScanner(reader)
+	}
 	readerChan := make(chan string)
 	readerTomb := &tomb.Tomb{}
 	readerTomb.Go(func() error {
@@ -479,10 +503,24 @@ func (d *DockerSource) TailDocker(container *ContainerConfig, outChan chan types
 			l.Src = container.Name
 			l.Process = true
 			l.Module = d.GetName()
-			evt := types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.LIVE}
+			var evt types.Event
+			if !d.Config.UseTimeMachine {
+				evt = types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.LIVE}
+			} else {
+				evt = types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.TIMEMACHINE}
+			}
 			linesRead.With(prometheus.Labels{"source": container.Name}).Inc()
 			outChan <- evt
 			d.logger.Debugf("Sent line to parsing: %+v", evt.Line.Raw)
+		case <-readerTomb.Dying():
+			//This case is to handle temporarily losing the connection to the docker socket
+			//The only known case currently is when using docker-socket-proxy (and maybe a docker daemon restart)
+			d.logger.Debugf("readerTomb dying for container %s, removing it from runningContainerState", container.Name)
+			deleteChan <- container
+			//Also reset the Since to avoid re-reading logs
+			d.Config.Since = time.Now().UTC().Format(time.RFC3339)
+			d.containerLogsOptions.Since = d.Config.Since
+			return nil
 		}
 	}
 }
@@ -496,7 +534,7 @@ func (d *DockerSource) DockerManager(in chan *ContainerConfig, deleteChan chan *
 				newContainer.t = &tomb.Tomb{}
 				newContainer.logger = d.logger.WithFields(log.Fields{"container_name": newContainer.Name})
 				newContainer.t.Go(func() error {
-					return d.TailDocker(newContainer, outChan)
+					return d.TailDocker(newContainer, outChan, deleteChan)
 				})
 				d.runningContainerState[newContainer.ID] = newContainer
 			}
