@@ -54,7 +54,8 @@ func readLine(scanner *bufio.Scanner, out chan string, errChan chan error) error
 	if errChan != nil && scanner.Err() != nil {
 		errChan <- scanner.Err()
 		close(errChan)
-		return scanner.Err()
+		// the error is already consumed by runJournalCtl
+		return nil //nolint:nilerr
 	}
 	if errChan != nil {
 		close(errChan)
@@ -79,7 +80,7 @@ func (j *JournalCtlSource) runJournalCtl(out chan types.Event, t *tomb.Tomb) err
 
 	stderrChan := make(chan string)
 	stdoutChan := make(chan string)
-	errChan := make(chan error)
+	errChan := make(chan error, 1)
 
 	logger := j.logger.WithField("src", j.src)
 
@@ -131,7 +132,12 @@ func (j *JournalCtlSource) runJournalCtl(out chan types.Event, t *tomb.Tomb) err
 			l.Process = true
 			l.Module = j.GetName()
 			linesRead.With(prometheus.Labels{"source": j.src}).Inc()
-			evt := types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.LIVE}
+			var evt types.Event
+			if !j.config.UseTimeMachine {
+				evt = types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.LIVE}
+			} else {
+				evt = types.Event{Line: l, Process: true, Type: types.LOG, ExpectMode: leaky.TIMEMACHINE}
+			}
 			out <- evt
 		case stderrLine := <-stderrChan:
 			logger.Warnf("Got stderr message : %s", stderrLine)
