@@ -42,7 +42,7 @@ func TestWatcherAuth(t *testing.T) {
 	log.Printf("URL is %s", urlx)
 	apiURL, err := url.Parse(urlx + "/")
 	if err != nil {
-		log.Fatalf("parsing api url: %s", apiURL)
+		t.Fatalf("parsing api url: %s", apiURL)
 	}
 
 	//ok auth
@@ -57,7 +57,7 @@ func TestWatcherAuth(t *testing.T) {
 	client, err := NewClient(mycfg)
 
 	if err != nil {
-		log.Fatalf("new api client: %s", err.Error())
+		t.Fatalf("new api client: %s", err)
 	}
 
 	_, err = client.Auth.AuthenticateWatcher(context.Background(), models.WatcherAuthRequest{
@@ -81,7 +81,7 @@ func TestWatcherAuth(t *testing.T) {
 	client, err = NewClient(mycfg)
 
 	if err != nil {
-		log.Fatalf("new api client: %s", err.Error())
+		t.Fatalf("new api client: %s", err)
 	}
 
 	_, err = client.Auth.AuthenticateWatcher(context.Background(), models.WatcherAuthRequest{
@@ -112,7 +112,7 @@ func TestWatcherRegister(t *testing.T) {
 	log.Printf("URL is %s", urlx)
 	apiURL, err := url.Parse(urlx + "/")
 	if err != nil {
-		log.Fatalf("parsing api url: %s", apiURL)
+		t.Fatalf("parsing api url: %s", apiURL)
 	}
 	client, err := RegisterClient(&Config{
 		MachineID:     "test_login",
@@ -158,7 +158,7 @@ func TestWatcherUnregister(t *testing.T) {
 	log.Printf("URL is %s", urlx)
 	apiURL, err := url.Parse(urlx + "/")
 	if err != nil {
-		log.Fatalf("parsing api url: %s", apiURL)
+		t.Fatalf("parsing api url: %s", apiURL)
 	}
 	mycfg := &Config{
 		MachineID:     "test_login",
@@ -171,7 +171,7 @@ func TestWatcherUnregister(t *testing.T) {
 	client, err := NewClient(mycfg)
 
 	if err != nil {
-		log.Fatalf("new api client: %s", err.Error())
+		t.Fatalf("new api client: %s", err)
 	}
 	_, err = client.Auth.UnregisterWatcher(context.Background())
 	if err != nil {
@@ -192,7 +192,7 @@ func TestWatcherEnroll(t *testing.T) {
 		_, _ = buf.ReadFrom(r.Body)
 		newStr := buf.String()
 		log.Debugf("body -> %s", newStr)
-		if newStr == `{"attachment_key":"goodkey","name":"","tags":[]}
+		if newStr == `{"attachment_key":"goodkey","name":"","tags":[],"overwrite":false}
 ` {
 			log.Print("good key")
 			w.WriteHeader(http.StatusOK)
@@ -211,7 +211,7 @@ func TestWatcherEnroll(t *testing.T) {
 	log.Printf("URL is %s", urlx)
 	apiURL, err := url.Parse(urlx + "/")
 	if err != nil {
-		log.Fatalf("parsing api url: %s", apiURL)
+		t.Fatalf("parsing api url: %s", apiURL)
 	}
 
 	mycfg := &Config{
@@ -225,14 +225,14 @@ func TestWatcherEnroll(t *testing.T) {
 	client, err := NewClient(mycfg)
 
 	if err != nil {
-		log.Fatalf("new api client: %s", err.Error())
+		t.Fatalf("new api client: %s", err)
 	}
 
-	_, err = client.Auth.EnrollWatcher(context.Background(), "goodkey", "", []string{})
+	_, err = client.Auth.EnrollWatcher(context.Background(), "goodkey", "", []string{}, false)
 	if err != nil {
 		t.Fatalf("unexpect enroll err: %s", err)
 	}
 
-	_, err = client.Auth.EnrollWatcher(context.Background(), "badkey", "", []string{})
+	_, err = client.Auth.EnrollWatcher(context.Background(), "badkey", "", []string{}, false)
 	assert.Contains(t, err.Error(), "the attachment key provided is not valid")
 }
