@@ -2,6 +2,7 @@ package controllers
 
 import (
 	"context"
+	"net"
 	"net/http"
 
 	"github.com/alexliesenfeld/health"
@@ -23,6 +24,8 @@ type Controller struct {
 	PluginChannel chan csplugin.ProfileAlert
 	Log           *log.Logger
 	ConsoleConfig *csconfig.ConsoleConfig
+	TrustedIPs    []net.IPNet
+	HandlerV1     *v1.Controller
 }
 
 func (c *Controller) Init() error {
@@ -53,11 +56,22 @@ func serveHealth() http.HandlerFunc {
 }
 
 func (c *Controller) NewV1() error {
-	handlerV1, err := v1.New(c.DBClient, c.Ectx, c.Profiles, c.CAPIChan, c.PluginChannel, *c.ConsoleConfig)
+	var err error
+
+	v1Config := v1.ControllerV1Config{
+		DbClient:      c.DBClient,
+		Ctx:           c.Ectx,
+		ProfilesCfg:   c.Profiles,
+		CapiChan:      c.CAPIChan,
+		PluginChannel: c.PluginChannel,
+		ConsoleConfig: *c.ConsoleConfig,
+		TrustedIPs:    c.TrustedIPs,
+	}
+
+	c.HandlerV1, err = v1.New(&v1Config)
 	if err != nil {
 		return err
 	}
-
 	c.Router.GET("/health", gin.WrapF(serveHealth()))
 	c.Router.Use(v1.PrometheusMiddleware())
 	c.Router.HandleMethodNotAllowed = true
@@ -69,30 +83,33 @@ func (c *Controller) NewV1() error {
 	})
 
 	groupV1 := c.Router.Group("/v1")
-	groupV1.POST("/watchers", handlerV1.CreateMachine)
-	groupV1.POST("/watchers/login", handlerV1.Middlewares.JWT.Middleware.LoginHandler)
+	groupV1.POST("/watchers", c.HandlerV1.CreateMachine)
+	groupV1.POST("/watchers/login", c.HandlerV1.Middlewares.JWT.Middleware.LoginHandler)
 
 	jwtAuth := groupV1.Group("")
-	jwtAuth.GET("/refresh_token", handlerV1.Middlewares.JWT.Middleware.RefreshHandler)
-	jwtAuth.Use(handlerV1.Middlewares.JWT.Middleware.MiddlewareFunc(), v1.PrometheusMachinesMiddleware())
+	jwtAuth.GET("/refresh_token", c.HandlerV1.Middlewares.JWT.Middleware.RefreshHandler)
+	jwtAuth.Use(c.HandlerV1.Middlewares.JWT.Middleware.MiddlewareFunc(), v1.PrometheusMachinesMiddleware())
 	{
-		jwtAuth.POST("/alerts", handlerV1.CreateAlert)
-		jwtAuth.GET("/alerts", handlerV1.FindAlerts)
-		jwtAuth.HEAD("/alerts", handlerV1.FindAlerts)
-		jwtAuth.GET("/alerts/:alert_id", handlerV1.FindAlertByID)
-		jwtAuth.HEAD("/alerts/:alert_id", handlerV1.FindAlertByID)
-		jwtAuth.DELETE("/alerts", handlerV1.DeleteAlerts)
-		jwtAuth.DELETE("/decisions", handlerV1.DeleteDecisions)
-		jwtAuth.DELETE("/decisions/:decision_id", handlerV1.DeleteDecisionById)
+		jwtAuth.POST("/alerts", c.HandlerV1.CreateAlert)
+		jwtAuth.GET("/alerts", c.HandlerV1.FindAlerts)
+		jwtAuth.HEAD("/alerts", c.HandlerV1.FindAlerts)
+		jwtAuth.GET("/alerts/:alert_id", c.HandlerV1.FindAlertByID)
+		jwtAuth.HEAD("/alerts/:alert_id", c.HandlerV1.FindAlertByID)
+		jwtAuth.DELETE("/alerts/:alert_id", c.HandlerV1.DeleteAlertByID)
+		jwtAuth.DELETE("/alerts", c.HandlerV1.DeleteAlerts)
+		jwtAuth.DELETE("/decisions", c.HandlerV1.DeleteDecisions)
+		jwtAuth.DELETE("/decisions/:decision_id", c.HandlerV1.DeleteDecisionById)
+		jwtAuth.GET("/heartbeat", c.HandlerV1.HeartBeat)
+
 	}
 
 	apiKeyAuth := groupV1.Group("")
-	apiKeyAuth.Use(handlerV1.Middlewares.APIKey.MiddlewareFunc(), v1.PrometheusBouncersMiddleware())
+	apiKeyAuth.Use(c.HandlerV1.Middlewares.APIKey.MiddlewareFunc(), v1.PrometheusBouncersMiddleware())
 	{
-		apiKeyAuth.GET("/decisions", handlerV1.GetDecision)
-		apiKeyAuth.HEAD("/decisions", handlerV1.GetDecision)
-		apiKeyAuth.GET("/decisions/stream", handlerV1.StreamDecision)
-		apiKeyAuth.HEAD("/decisions/stream", handlerV1.StreamDecision)
+		apiKeyAuth.GET("/decisions", c.HandlerV1.GetDecision)
+		apiKeyAuth.HEAD("/decisions", c.HandlerV1.GetDecision)
+		apiKeyAuth.GET("/decisions/stream", c.HandlerV1.StreamDecision)
+		apiKeyAuth.HEAD("/decisions/stream", c.HandlerV1.StreamDecision)
 	}
 
 	return nil
