@@ -2,12 +2,17 @@ package v1
 
 import (
 	"context"
+	"net"
+
+	//"github.com/crowdsecurity/crowdsec/pkg/apiserver/controllers"
 
 	middlewares "github.com/crowdsecurity/crowdsec/pkg/apiserver/middlewares/v1"
 	"github.com/crowdsecurity/crowdsec/pkg/csconfig"
 	"github.com/crowdsecurity/crowdsec/pkg/csplugin"
+	"github.com/crowdsecurity/crowdsec/pkg/csprofiles"
 	"github.com/crowdsecurity/crowdsec/pkg/database"
 	"github.com/crowdsecurity/crowdsec/pkg/models"
+	"github.com/pkg/errors"
 )
 
 type Controller struct {
@@ -15,27 +20,44 @@ type Controller struct {
 	DBClient      *database.Client
 	APIKeyHeader  string
 	Middlewares   *middlewares.Middlewares
-	Profiles      []*csconfig.ProfileCfg
+	Profiles      []*csprofiles.Runtime
 	CAPIChan      chan []*models.Alert
 	PluginChannel chan csplugin.ProfileAlert
 	ConsoleConfig csconfig.ConsoleConfig
+	TrustedIPs    []net.IPNet
 }
 
-func New(dbClient *database.Client, ctx context.Context, profiles []*csconfig.ProfileCfg, capiChan chan []*models.Alert, pluginChannel chan csplugin.ProfileAlert, consoleConfig csconfig.ConsoleConfig) (*Controller, error) {
+type ControllerV1Config struct {
+	DbClient      *database.Client
+	Ctx           context.Context
+	ProfilesCfg   []*csconfig.ProfileCfg
+	CapiChan      chan []*models.Alert
+	PluginChannel chan csplugin.ProfileAlert
+	ConsoleConfig csconfig.ConsoleConfig
+	TrustedIPs    []net.IPNet
+}
+
+func New(cfg *ControllerV1Config) (*Controller, error) {
 	var err error
+
+	profiles, err := csprofiles.NewProfile(cfg.ProfilesCfg)
+	if err != nil {
+		return &Controller{}, errors.Wrapf(err, "failed to compile profiles")
+	}
+
 	v1 := &Controller{
-		Ectx:          ctx,
-		DBClient:      dbClient,
+		Ectx:          cfg.Ctx,
+		DBClient:      cfg.DbClient,
 		APIKeyHeader:  middlewares.APIKeyHeader,
 		Profiles:      profiles,
-		CAPIChan:      capiChan,
-		PluginChannel: pluginChannel,
-		ConsoleConfig: consoleConfig,
+		CAPIChan:      cfg.CapiChan,
+		PluginChannel: cfg.PluginChannel,
+		ConsoleConfig: cfg.ConsoleConfig,
+		TrustedIPs:    cfg.TrustedIPs,
 	}
-	v1.Middlewares, err = middlewares.NewMiddlewares(dbClient)
+	v1.Middlewares, err = middlewares.NewMiddlewares(cfg.DbClient)
 	if err != nil {
 		return v1, err
 	}
-
 	return v1, nil
 }
