@@ -2,19 +2,17 @@ package cwhub
 
 import (
 	"crypto/sha256"
-	"path/filepath"
-	"strings"
-
-	//"errors"
 	"fmt"
 	"io"
 	"os"
+	"path/filepath"
+	"sort"
+	"strings"
 
 	"github.com/enescakir/emoji"
 	"github.com/pkg/errors"
-	"golang.org/x/mod/semver"
-
 	log "github.com/sirupsen/logrus"
+	"golang.org/x/mod/semver"
 )
 
 /*managed configuration types*/
@@ -119,14 +117,14 @@ func getSHA256(filepath string) (string, error) {
 	/* Digest of file */
 	f, err := os.Open(filepath)
 	if err != nil {
-		return "", fmt.Errorf("unable to open '%s' : %s", filepath, err.Error())
+		return "", fmt.Errorf("unable to open '%s' : %s", filepath, err)
 	}
 
 	defer f.Close()
 
 	h := sha256.New()
 	if _, err := io.Copy(h, f); err != nil {
-		return "", fmt.Errorf("unable to calculate sha256 of '%s': %s", filepath, err.Error())
+		return "", fmt.Errorf("unable to calculate sha256 of '%s': %s", filepath, err)
 	}
 
 	return fmt.Sprintf("%x", h.Sum(nil)), nil
@@ -173,13 +171,10 @@ func GetItemByPath(itemType string, itemPath string) (*Item, error) {
 	if m := GetItemMap(itemType); m != nil {
 		if v, ok := m[finalName]; ok {
 			return &v, nil
-		} else {
-			return nil, fmt.Errorf("%s not found in %s", finalName, itemType)
 		}
-	} else {
-		return nil, fmt.Errorf("item type %s doesn't exist", itemType)
+		return nil, fmt.Errorf("%s not found in %s", finalName, itemType)
 	}
-
+	return nil, fmt.Errorf("item type %s doesn't exist", itemType)
 }
 
 func GetItem(itemType string, itemName string) *Item {
@@ -213,25 +208,21 @@ func DisplaySummary() {
 
 //returns: human-text, Enabled, Warning, Unmanaged
 func ItemStatus(v Item) (string, bool, bool, bool) {
-	var Ok, Warning, Managed bool
-	var strret string
-
-	if !v.Installed {
-		strret = "disabled"
-		Ok = false
-	} else {
+	strret := "disabled"
+	Ok := false
+	if v.Installed {
 		Ok = true
 		strret = "enabled"
 	}
 
+	Managed := true
 	if v.Local {
 		Managed = false
 		strret += ",local"
-	} else {
-		Managed = true
 	}
 
 	//tainted or out of date
+	Warning := false
 	if v.Tainted {
 		Warning = true
 		strret += ",tainted"
@@ -242,10 +233,10 @@ func ItemStatus(v Item) (string, bool, bool, bool) {
 	return strret, Ok, Warning, Managed
 }
 
-func GetUpstreamInstalledScenariosAsString() ([]string, error) {
+func GetInstalledScenariosAsString() ([]string, error) {
 	var retStr []string
 
-	items, err := GetUpstreamInstalledScenarios()
+	items, err := GetInstalledScenarios()
 	if err != nil {
 		return nil, errors.Wrap(err, "while fetching scenarios")
 	}
@@ -255,14 +246,95 @@ func GetUpstreamInstalledScenariosAsString() ([]string, error) {
 	return retStr, nil
 }
 
-func GetUpstreamInstalledScenarios() ([]Item, error) {
+func GetInstalledScenarios() ([]Item, error) {
 	var retItems []Item
 
 	if _, ok := hubIdx[SCENARIOS]; !ok {
 		return nil, fmt.Errorf("no scenarios in hubIdx")
 	}
 	for _, item := range hubIdx[SCENARIOS] {
-		if item.Installed && !item.Tainted {
+		if item.Installed {
+			retItems = append(retItems, item)
+		}
+	}
+	return retItems, nil
+}
+
+func GetInstalledParsers() ([]Item, error) {
+	var retItems []Item
+
+	if _, ok := hubIdx[PARSERS]; !ok {
+		return nil, fmt.Errorf("no parsers in hubIdx")
+	}
+	for _, item := range hubIdx[PARSERS] {
+		if item.Installed {
+			retItems = append(retItems, item)
+		}
+	}
+	return retItems, nil
+}
+
+func GetInstalledParsersAsString() ([]string, error) {
+	var retStr []string
+
+	items, err := GetInstalledParsers()
+	if err != nil {
+		return nil, errors.Wrap(err, "while fetching parsers")
+	}
+	for _, it := range items {
+		retStr = append(retStr, it.Name)
+	}
+	return retStr, nil
+}
+
+func GetInstalledPostOverflows() ([]Item, error) {
+	var retItems []Item
+
+	if _, ok := hubIdx[PARSERS_OVFLW]; !ok {
+		return nil, fmt.Errorf("no post overflows in hubIdx")
+	}
+	for _, item := range hubIdx[PARSERS_OVFLW] {
+		if item.Installed {
+			retItems = append(retItems, item)
+		}
+	}
+	return retItems, nil
+}
+
+func GetInstalledPostOverflowsAsString() ([]string, error) {
+	var retStr []string
+
+	items, err := GetInstalledPostOverflows()
+	if err != nil {
+		return nil, errors.Wrap(err, "while fetching post overflows")
+	}
+	for _, it := range items {
+		retStr = append(retStr, it.Name)
+	}
+	return retStr, nil
+}
+
+func GetInstalledCollectionsAsString() ([]string, error) {
+	var retStr []string
+
+	items, err := GetInstalledCollections()
+	if err != nil {
+		return nil, errors.Wrap(err, "while fetching collections")
+	}
+	for _, it := range items {
+		retStr = append(retStr, it.Name)
+	}
+	return retStr, nil
+}
+
+func GetInstalledCollections() ([]Item, error) {
+	var retItems []Item
+
+	if _, ok := hubIdx[COLLECTIONS]; !ok {
+		return nil, fmt.Errorf("no collection in hubIdx")
+	}
+	for _, item := range hubIdx[COLLECTIONS] {
+		if item.Installed {
 			retItems = append(retItems, item)
 		}
 	}
@@ -291,5 +363,6 @@ func GetHubStatusForItemType(itemType string, name string, all bool) []ItemHubSt
 		//Check the item status
 		ret = append(ret, item.toHubStatus())
 	}
+	sort.Slice(ret, func(i, j int) bool { return ret[i].Name < ret[j].Name })
 	return ret
 }
