@@ -2,8 +2,10 @@ package schema
 
 import (
 	"entgo.io/ent"
+	"entgo.io/ent/dialect"
 	"entgo.io/ent/schema/edge"
 	"entgo.io/ent/schema/field"
+	"entgo.io/ent/schema/index"
 	"github.com/crowdsecurity/crowdsec/pkg/types"
 )
 
@@ -21,7 +23,9 @@ func (Decision) Fields() []ent.Field {
 		field.Time("updated_at").
 			Default(types.UtcNow).
 			UpdateDefault(types.UtcNow).Nillable().Optional(),
-		field.Time("until"),
+		field.Time("until").Nillable().Optional().SchemaType(map[string]string{
+			dialect.MySQL: "datetime",
+		}),
 		field.String("scenario"),
 		field.String("type"),
 		field.Int64("start_ip").Optional(),
@@ -44,3 +48,11 @@ func (Decision) Edges() []ent.Edge {
 			Unique(),
 	}
 }
+
+func (Decision) Indexes() []ent.Index {
+	return []ent.Index{
+		index.Fields("start_ip", "end_ip"),
+		index.Fields("value"),
+		index.Fields("until"),
+	}
+}
