@@ -1,11 +1,10 @@
 package schema
 
 import (
-	"time"
-
-	"github.com/facebook/ent"
-	"github.com/facebook/ent/schema/edge"
-	"github.com/facebook/ent/schema/field"
+	"entgo.io/ent"
+	"entgo.io/ent/schema/edge"
+	"entgo.io/ent/schema/field"
+	"github.com/crowdsecurity/crowdsec/pkg/types"
 )
 
 // Event holds the schema definition for the Event entity.
@@ -17,11 +16,13 @@ type Event struct {
 func (Event) Fields() []ent.Field {
 	return []ent.Field{
 		field.Time("created_at").
-			Default(time.Now),
+			Default(types.UtcNow).
+			UpdateDefault(types.UtcNow).Nillable().Optional(),
 		field.Time("updated_at").
-			Default(time.Now),
+			Default(types.UtcNow).
+			UpdateDefault(types.UtcNow).Nillable().Optional(),
 		field.Time("time"),
-		field.String("serialized").MaxLen(4095),
+		field.String("serialized").MaxLen(8191),
 	}
 }
 
