@@ -12,7 +12,7 @@ import (
 	"github.com/oschwald/maxminddb-golang"
 )
 
-func IpToRange(field string, p *types.Event, ctx interface{}) (map[string]string, error) {
+func IpToRange(field string, p *types.Event, ctx interface{}, plog *log.Entry) (map[string]string, error) {
 	var dummy interface{}
 	ret := make(map[string]string)
 
@@ -21,23 +21,23 @@ func IpToRange(field string, p *types.Event, ctx interface{}) (map[string]string
 	}
 	ip := net.ParseIP(field)
 	if ip == nil {
-		log.Infof("Can't parse ip %s, no range enrich", field)
+		plog.Infof("Can't parse ip %s, no range enrich", field)
 		return nil, nil
 	}
 	net, ok, err := ctx.(*maxminddb.Reader).LookupNetwork(ip, &dummy)
 	if err != nil {
-		log.Errorf("Failed to fetch network for %s : %v", ip.String(), err)
+		plog.Errorf("Failed to fetch network for %s : %v", ip.String(), err)
 		return nil, nil
 	}
 	if !ok {
-		log.Debugf("Unable to find range of %s", ip.String())
+		plog.Debugf("Unable to find range of %s", ip.String())
 		return nil, nil
 	}
 	ret["SourceRange"] = net.String()
 	return ret, nil
 }
 
-func GeoIpASN(field string, p *types.Event, ctx interface{}) (map[string]string, error) {
+func GeoIpASN(field string, p *types.Event, ctx interface{}, plog *log.Entry) (map[string]string, error) {
 	ret := make(map[string]string)
 	if field == "" {
 		return nil, nil
@@ -45,44 +45,56 @@ func GeoIpASN(field string, p *types.Event, ctx interface{}) (map[string]string,
 
 	ip := net.ParseIP(field)
 	if ip == nil {
-		log.Infof("Can't parse ip %s, no ASN enrich", ip)
+		plog.Infof("Can't parse ip %s, no ASN enrich", ip)
 		return nil, nil
 	}
 	record, err := ctx.(*geoip2.Reader).ASN(ip)
 	if err != nil {
-		log.Errorf("Unable to enrich ip '%s'", field)
-		return nil, nil
+		plog.Errorf("Unable to enrich ip '%s'", field)
+		return nil, nil //nolint:nilerr
 	}
 	ret["ASNNumber"] = fmt.Sprintf("%d", record.AutonomousSystemNumber)
 	ret["ASNumber"] = fmt.Sprintf("%d", record.AutonomousSystemNumber)
 	ret["ASNOrg"] = record.AutonomousSystemOrganization
 
-	log.Tracef("geoip ASN %s -> %s, %s", field, ret["ASNNumber"], ret["ASNOrg"])
+	plog.Tracef("geoip ASN %s -> %s, %s", field, ret["ASNNumber"], ret["ASNOrg"])
 
 	return ret, nil
 }
 
-func GeoIpCity(field string, p *types.Event, ctx interface{}) (map[string]string, error) {
+func GeoIpCity(field string, p *types.Event, ctx interface{}, plog *log.Entry) (map[string]string, error) {
 	ret := make(map[string]string)
 	if field == "" {
 		return nil, nil
 	}
 	ip := net.ParseIP(field)
 	if ip == nil {
-		log.Infof("Can't parse ip %s, no City enrich", ip)
+		plog.Infof("Can't parse ip %s, no City enrich", ip)
 		return nil, nil
 	}
 	record, err := ctx.(*geoip2.Reader).City(ip)
 	if err != nil {
-		log.Debugf("Unable to enrich ip '%s'", ip)
-		return nil, nil
+		plog.Debugf("Unable to enrich ip '%s'", ip)
+		return nil, nil //nolint:nilerr
 	}
-	ret["IsoCode"] = record.Country.IsoCode
-	ret["IsInEU"] = strconv.FormatBool(record.Country.IsInEuropeanUnion)
+	if record.Country.IsoCode != "" {
+		ret["IsoCode"] = record.Country.IsoCode
+		ret["IsInEU"] = strconv.FormatBool(record.Country.IsInEuropeanUnion)
+	} else if record.RegisteredCountry.IsoCode != "" {
+		ret["IsoCode"] = record.RegisteredCountry.IsoCode
+		ret["IsInEU"] = strconv.FormatBool(record.RegisteredCountry.IsInEuropeanUnion)
+	} else if record.RepresentedCountry.IsoCode != "" {
+		ret["IsoCode"] = record.RepresentedCountry.IsoCode
+		ret["IsInEU"] = strconv.FormatBool(record.RepresentedCountry.IsInEuropeanUnion)
+	} else {
+		ret["IsoCode"] = ""
+		ret["IsInEU"] = strconv.FormatBool(false)
+	}
+
 	ret["Latitude"] = fmt.Sprintf("%f", record.Location.Latitude)
 	ret["Longitude"] = fmt.Sprintf("%f", record.Location.Longitude)
 
-	log.Tracef("geoip City %s -> %s, %s", field, ret["IsoCode"], ret["IsInEU"])
+	plog.Tracef("geoip City %s -> %s, %s", field, ret["IsoCode"], ret["IsInEU"])
 
 	return ret, nil
 }
