@@ -18,7 +18,7 @@ do
 		BASE=${2}
 		shift #past argument
 		shift
-		;;  
+		;;
 	-h|--help)
 		usage
 		exit 0
@@ -47,7 +47,7 @@ PARSER_S02="$PARSER_DIR/s02-enrich"
 SCENARIOS_DIR="$CONFIG_DIR/scenarios"
 POSTOVERFLOWS_DIR="$CONFIG_DIR/postoverflows"
 HUB_DIR="$CONFIG_DIR/hub"
-PLUGINS="http slack splunk"
+PLUGINS="http slack splunk email"
 PLUGINS_DIR="plugins"
 NOTIF_DIR="notifications"
 
@@ -70,13 +70,13 @@ create_arbo() {
 	mkdir -p "$POSTOVERFLOWS_DIR"
 	mkdir -p "$CSCLI_DIR"
 	mkdir -p "$HUB_DIR"
-	mkdir -p $CONFIG_DIR/$NOTIF_DIR/$plugin
-	mkdir -p $BASE/$PLUGINS_DIR
+	mkdir -p "$CONFIG_DIR/$NOTIF_DIR/$plugin"
+	mkdir -p "$BASE/$PLUGINS_DIR"
 }
 
 copy_files() {
 	cp "./config/profiles.yaml" "$CONFIG_DIR"
-	cp  "./config/simulation.yaml" "$CONFIG_DIR"
+	cp "./config/simulation.yaml" "$CONFIG_DIR"
 	cp "./cmd/crowdsec/crowdsec" "$BASE"
 	cp "./cmd/crowdsec-cli/cscli" "$BASE"
 	cp -r "./config/patterns" "$CONFIG_DIR"
