@@ -3,6 +3,10 @@
 set -o pipefail
 #set -x
 
+skip_tmp_acquis() {
+    [[ "${TMP_ACQUIS_FILE_SKIP}" == "skip" ]]
+}
+
 
 RED='\033[0;31m'
 BLUE='\033[0;34m'
@@ -43,10 +47,8 @@ else
 fi
 
 ACQUIS_PATH="${CROWDSEC_CONFIG_PATH}"
-TMP_ACQUIS_FILE="tmp-acquis.yaml"
 ACQUIS_TARGET="${ACQUIS_PATH}/acquis.yaml"
 
-PID_DIR="${CROWDSEC_RUN_DIR}"
 SYSTEMD_PATH_FILE="/etc/systemd/system/crowdsec.service"
 
 PATTERNS_FOLDER="config/patterns"
@@ -78,7 +80,7 @@ SPLUNK_PLUGIN_CONFIG="./plugins/notifications/splunk/splunk.yaml"
 EMAIL_PLUGIN_CONFIG="./plugins/notifications/email/email.yaml"
 
 BACKUP_DIR=$(mktemp -d)
-rm -rf $BACKUP_DIR
+rm -rf -- "$BACKUP_DIR"
 
 log_info() {
     msg=$1
@@ -219,7 +221,7 @@ in_array() {
     shift
     array=("$@")
     for element in "${array[@]}"; do
-        if [[ ${str} == *${element}* ]]; then
+        if [[ ${str} == crowdsecurity/${element} ]]; then
             return 0
         fi
     done
@@ -287,7 +289,7 @@ genyamllog() {
     echo "labels:"  >> ${TMP_ACQUIS_FILE}
     echo "  "${log_input_tags[${service}]}  >> ${TMP_ACQUIS_FILE}
     echo "---"  >> ${TMP_ACQUIS_FILE}
-    log_dbg "tmp acquisition file generated to: ${TMP_ACQUIS_FILE}"
+    log_dbg "${ACQUIS_FILE_MSG}"
 }
 
 genyamljournal() {
@@ -301,10 +303,18 @@ genyamljournal() {
     echo "labels:"  >> ${TMP_ACQUIS_FILE}
     echo "  "${log_input_tags[${service}]}  >> ${TMP_ACQUIS_FILE}
     echo "---"  >> ${TMP_ACQUIS_FILE}
-    log_dbg "tmp acquisition file generated to: ${TMP_ACQUIS_FILE}"
+    log_dbg "${ACQUIS_FILE_MSG}"
 }
 
 genacquisition() {
+    if skip_tmp_acquis; then 
+        TMP_ACQUIS_FILE="${ACQUIS_TARGET}"
+        ACQUIS_FILE_MSG="acquisition file generated to: ${TMP_ACQUIS_FILE}"
+    else
+        TMP_ACQUIS_FILE="tmp-acquis.yaml"
+        ACQUIS_FILE_MSG="tmp acquisition file generated to: ${TMP_ACQUIS_FILE}"
+    fi
+
     log_dbg "Found following services : "${DETECTED_SERVICES[@]}
     for PSVG in ${DETECTED_SERVICES[@]} ; do
         find_logs_for ${PSVG}
@@ -322,7 +332,7 @@ detect_cs_install () {
     if [[ -f "$CROWDSEC_BIN_INSTALLED" ]]; then
         log_warn "Crowdsec is already installed !"
         echo ""
-        echo "We recommand to upgrade : sudo ./wizard.sh --upgrade "
+        echo "We recommend to upgrade : sudo ./wizard.sh --upgrade "
         echo "If you want to install it anyway, please use '--force'."
         echo ""
         echo "Run : sudo ./wizard.sh -i --force"
@@ -353,7 +363,7 @@ check_cs_version () {
         if [[ $ACTION != "upgrade" ]] ; then 
             if [[ ${FORCE_MODE} == "false" ]]; then
                 echo ""
-                echo "We recommand to upgrade with : sudo ./wizard.sh --upgrade "
+                echo "We recommend to upgrade with : sudo ./wizard.sh --upgrade "
                 echo "If you want to $ACTION anyway, please use '--force'."
                 echo ""
                 echo "Run : sudo ./wizard.sh --$ACTION --force"
@@ -365,7 +375,7 @@ check_cs_version () {
         if [[ $ACTION != "binupgrade" ]] ; then 
             if [[ ${FORCE_MODE} == "false" ]]; then
                 echo ""
-                echo "We recommand to upgrade binaries only : sudo ./wizard.sh --binupgrade "
+                echo "We recommend to upgrade binaries only : sudo ./wizard.sh --binupgrade "
                 echo "If you want to $ACTION anyway, please use '--force'."
                 echo ""
                 echo "Run : sudo ./wizard.sh --$ACTION --force"
@@ -376,7 +386,7 @@ check_cs_version () {
         log_warn "new version ($NEW_CS_VERSION) is same as current version ($CURRENT_CS_VERSION) !"
         if [[ ${FORCE_MODE} == "false" ]]; then
             echo ""
-            echo "We recommand to $ACTION only if it's an higher version. "
+            echo "We recommend to $ACTION only if it's an higher version. "
             echo "If it's an RC version (vX.X.X-rc) you can upgrade it using '--force'."
             echo ""
             echo "Run : sudo ./wizard.sh --$ACTION --force"
@@ -402,7 +412,7 @@ install_crowdsec() {
 
     ## end tmp
 
-    install -v -m 644 -D ./config/config.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 600 -D ./config/config.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
     install -v -m 644 -D ./config/dev.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
     install -v -m 644 -D ./config/user.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
     install -v -m 644 -D ./config/acquis.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
@@ -410,10 +420,9 @@ install_crowdsec() {
     install -v -m 644 -D ./config/simulation.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
     install -v -m 644 -D ./config/"${CONSOLE_FILE}" "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
 
-    mkdir -p ${PID_DIR} || exit
-    PID=${PID_DIR} DATA=${CROWDSEC_DATA_DIR} CFG=${CROWDSEC_CONFIG_PATH} envsubst '$CFG $PID $DATA' < ./config/user.yaml > ${CROWDSEC_CONFIG_PATH}"/user.yaml" || log_fatal "unable to generate user configuration file"
+    DATA=${CROWDSEC_DATA_DIR} CFG=${CROWDSEC_CONFIG_PATH} envsubst '$CFG $DATA' < ./config/user.yaml > ${CROWDSEC_CONFIG_PATH}"/user.yaml" || log_fatal "unable to generate user configuration file"
     if [[ ${DOCKER_MODE} == "false" ]]; then
-        CFG=${CROWDSEC_CONFIG_PATH} PID=${PID_DIR} BIN=${CROWDSEC_BIN_INSTALLED} envsubst '$CFG $PID $BIN' < ./config/crowdsec.service > "${SYSTEMD_PATH_FILE}" || log_fatal "unable to crowdsec systemd file"
+        CFG=${CROWDSEC_CONFIG_PATH} BIN=${CROWDSEC_BIN_INSTALLED} envsubst '$CFG $BIN' < ./config/crowdsec.service > "${SYSTEMD_PATH_FILE}" || log_fatal "unable to crowdsec systemd file"
     fi
     install_bins
 
@@ -504,13 +513,13 @@ install_plugins(){
         cp -n ${SLACK_PLUGIN_CONFIG} /etc/crowdsec/notifications/
         cp -n ${SPLUNK_PLUGIN_CONFIG} /etc/crowdsec/notifications/
         cp -n ${HTTP_PLUGIN_CONFIG} /etc/crowdsec/notifications/
-        cp -n ${EMAIL_PLUGIN_CONFIG} /etc/crowdsec/notifications
+        cp -n ${EMAIL_PLUGIN_CONFIG} /etc/crowdsec/notifications/
     fi
 }
 
 check_running_bouncers() {
     #when uninstalling, check if user still has bouncers
-    BOUNCERS_COUNT=$(${CSCLI_BIN} bouncers list -o=json | jq '. | length')
+    BOUNCERS_COUNT=$(${CSCLI_BIN} bouncers list -o=raw | tail -n +2 | wc -l)
     if [[ ${BOUNCERS_COUNT} -gt 0 ]] ; then
         if [[ ${FORCE_MODE} == "false" ]]; then
             echo "WARNING : You have at least one bouncer registered (cscli bouncers list)."
@@ -609,7 +618,9 @@ main() {
         ${CSCLI_BIN_INSTALLED} hub update
         install_collection
         genacquisition
-        mv "${TMP_ACQUIS_FILE}" "${ACQUIS_TARGET}"
+        if ! skip_tmp_acquis; then
+            mv "${TMP_ACQUIS_FILE}" "${ACQUIS_TARGET}"
+        fi
 
         return
     fi
@@ -668,7 +679,9 @@ main() {
 
         # Generate acquisition file and move it to the right folder
         genacquisition
-        mv "${TMP_ACQUIS_FILE}" "${ACQUIS_TARGET}"
+        if ! skip_tmp_acquis; then
+            mv "${TMP_ACQUIS_FILE}" "${ACQUIS_TARGET}"
+        fi
         log_info "acquisition file path: ${ACQUIS_TARGET}"
         # Install collections according to detected services
         log_dbg "Installing needed collections ..."
@@ -679,7 +692,6 @@ main() {
         mkdir -p "${PATTERNS_PATH}"
         cp "./${PATTERNS_FOLDER}/"* "${PATTERNS_PATH}/"
 
-
         # api register
         ${CSCLI_BIN_INSTALLED} machines add --force "$(cat /etc/machine-id)" -a -f "${CROWDSEC_CONFIG_PATH}/${CLIENT_SECRETS}" || log_fatal "unable to add machine to the local API"
         log_dbg "Crowdsec LAPI registered" 
@@ -696,7 +708,9 @@ main() {
 
     if [[ "$1" == "detect" ]];
     then
-        rm -f "${TMP_ACQUIS_FILE}"
+        if ! skip_tmp_acquis; then
+            rm -f "${TMP_ACQUIS_FILE}"
+        fi
         detect_services
         if [[ ${DETECTED_SERVICES} == "" ]] ; then 
             log_err "No detected or selected services, stopping."
@@ -705,7 +719,9 @@ main() {
         log_info "Found ${#DETECTED_SERVICES[@]} supported services running:"
         genacquisition
         cat "${TMP_ACQUIS_FILE}"
-        rm "${TMP_ACQUIS_FILE}"
+        if ! skip_tmp_acquis; then
+            rm "${TMP_ACQUIS_FILE}"
+        fi
         return
     fi
 
